Processor.App.OutStreamer.outstreamer.OutStreamer.stream
========================================================

.. currentmodule:: Processor.App.OutStreamer.outstreamer

.. automethod:: OutStreamer.stream